@@ -5,12 +5,12 @@ use {
 
 /** A basic interface for a `Map` */
 pub trait Map<K, V> {
-    fn get(&self, key: K) -> Option<&V>;
+    fn get(&self, key: &K) -> Option<&V>;
 }
 
 pub trait MapMut<K, V> {
     fn insert(&mut self, key: K, value: V) -> Option<V>;
-    fn remove(&mut self, key: K) -> Option<V>;
+    fn remove(&mut self, key: &K) -> Option<V>;
 }
 
 pub trait MapUtil<'a, K, V> {
